@@ -1,3 +1,5 @@
+import k4a_module
+
 from .calibration import Calibration, CalibrationType
 from .capture import PyK4ACapture
 from .config import (
@@ -13,6 +15,7 @@ from .config import (
 from .errors import K4AException, K4ATimeoutException
 from .playback import PyK4APlayback, SeekOrigin
 from .pyk4a import ColorControlCapabilities, PyK4A
+from .record import PyK4ARecord
 from .transformation import (
     color_image_to_depth_camera,
     depth_image_to_color_camera,
@@ -21,6 +24,10 @@ from .transformation import (
 )
 
 
+def connected_device_count() -> int:
+    return k4a_module.device_get_installed_count()
+
+
 __all__ = (
     "Calibration",
     "CalibrationType",
@@ -43,4 +50,6 @@ __all__ = (
     "depth_image_to_point_cloud",
     "depth_image_to_color_camera",
     "depth_image_to_color_camera_custom",
+    "PyK4ARecord",
+    "connected_device_count",
 )
